FlutterLightweightStoreModule class

A Wrapper that one instance for one module

Constructors

FlutterLightweightStoreModule(String module, {String? aesKey, String? aesIV, bool? isAsyncApply, bool? isKeepKeyClearText})

Properties

aesIV ↔ String?
getter/setter pair
aesKey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAsyncApply ↔ bool?
getter/setter pair
isKeepKeyClearText ↔ bool?
getter/setter pair
module ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String key) → Future<bool>
dispose() → Future<bool>
getBoolean(String key) → Future<bool?>
getDouble(String key) → Future<double?>
getInt(String key) → Future<int?>
getString(String key) → Future<String?>
Getters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeKey(String key) → Future<bool>
setBoolean(String key, bool value) → Future<bool>
setDouble(String key, double value) → Future<bool>
setInt(String key, int value) → Future<bool>
setString(String key, String value) → Future<bool>
Setters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited